@@ -24,11 +24,7 @@
 #include <time.h>
 #include <libintl.h>
 #include <math.h>
-#ifdef HAVE_LIBSOUP_GNOME
-#include <libsoup/soup-gnome.h>
-#else
 #include <libsoup/soup.h>
-#endif
 
 #include "weather.h"
 #include "mateweather-location.h"
